==> batch-task-1.8-sources.jar: hudson/plugins/batch_task/Messages.java <==
// CHECKSTYLE:OFF

package hudson.plugins.batch_task;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;

@SuppressWarnings({
    "",
    "PMD"
})
public class Messages {

    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * {0,choice,1#Task|1&lt;Tasks}
     * 
     */
    public static String BatchTaskAction_DisplayName(Object arg1) {
        return holder.format("BatchTaskAction.DisplayName", arg1);
    }

    /**
     * {0,choice,1#Task|1&lt;Tasks}
     * 
     */
    public static Localizable _BatchTaskAction_DisplayName(Object arg1) {
        return new Localizable(holder, "BatchTaskAction.DisplayName", arg1);
    }

    /**
     * Invoke batch tasks of other projects
     * 
     */
    public static String BatchTaskInvoker_DisplayName() {
        return holder.format("BatchTaskInvoker.DisplayName");
    }

    /**
     * Invoke batch tasks of other projects
     * 
     */
    public static Localizable _BatchTaskInvoker_DisplayName() {
        return new Localizable(holder, "BatchTaskInvoker.DisplayName");
    }

    /**
     * No such task exists: {0}. Perhaps you meant {1}
     * 
     */
    public static String BatchTaskInvoker_NoSuchTask(Object arg1, Object arg2) {
        return holder.format("BatchTaskInvoker.NoSuchTask", arg1, arg2);
    }

    /**
     * No such task exists: {0}. Perhaps you meant {1}
     * 
     */
    public static Localizable _BatchTaskInvoker_NoSuchTask(Object arg1, Object arg2) {
        return new Localizable(holder, "BatchTaskInvoker.NoSuchTask", arg1, arg2);
    }

    /**
     * Executed Tasks
     * 
     */
    public static String BatchRunAction_DisplayName() {
        return holder.format("BatchRunAction.DisplayName");
    }

    /**
     * Executed Tasks
     * 
     */
    public static Localizable _BatchRunAction_DisplayName() {
        return new Localizable(holder, "BatchRunAction.DisplayName");
    }

    /**
     * No such task exists: {0}. In fact, no batch tasks exist at all
     * 
     */
    public static String BatchTaskInvoker_NoBatchTaskExists(Object arg1) {
        return holder.format("BatchTaskInvoker.NoBatchTaskExists", arg1);
    }

    /**
     * No such task exists: {0}. In fact, no batch tasks exist at all
     * 
     */
    public static Localizable _BatchTaskInvoker_NoBatchTaskExists(Object arg1) {
        return new Localizable(holder, "BatchTaskInvoker.NoBatchTaskExists", arg1);
    }

    /**
     * Batch tasks
     * 
     */
    public static String BatchTaskProperty_DisplayName() {
        return holder.format("BatchTaskProperty.DisplayName");
    }

    /**
     * Batch tasks
     * 
     */
    public static Localizable _BatchTaskProperty_DisplayName() {
        return new Localizable(holder, "BatchTaskProperty.DisplayName");
    }

    /**
     * No such project exists: {0}
     * 
     */
    public static String BatchTaskInvoker_NoSuchProject(Object arg1) {
        return holder.format("BatchTaskInvoker.NoSuchProject", arg1);
    }

    /**
     * No such project exists: {0}
     * 
     */
    public static Localizable _BatchTaskInvoker_NoSuchProject(Object arg1) {
        return new Localizable(holder, "BatchTaskInvoker.NoSuchProject", arg1);
    }

    /**
     * Invoking {0} - {1} #{2}
     * 
     */
    public static String BatchTaskInvoker_Invoking(Object arg1, Object arg2, Object arg3) {
        return holder.format("BatchTaskInvoker.Invoking", arg1, arg2, arg3);
    }

    /**
     * Invoking {0} - {1} #{2}
     * 
     */
    public static Localizable _BatchTaskInvoker_Invoking(Object arg1, Object arg2, Object arg3) {
        return new Localizable(holder, "BatchTaskInvoker.Invoking", arg1, arg2, arg3);
    }

}

==> batch-task-1.14-sources.jar: hudson/plugins/batch_task/Messages.java <==
// CHECKSTYLE:OFF

package hudson.plugins.batch_task;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;

@SuppressWarnings({
    "",
    "PMD"
})
public class Messages {

    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * {0,choice,1#Task|1&lt;Tasks}
     * 
     */
    public static String BatchTaskAction_DisplayName(Object arg1) {
        return holder.format("BatchTaskAction.DisplayName", arg1);
    }

    /**
     * {0,choice,1#Task|1&lt;Tasks}
     * 
     */
    public static Localizable _BatchTaskAction_DisplayName(Object arg1) {
        return new Localizable(holder, "BatchTaskAction.DisplayName", arg1);
    }

    /**
     * Invoke batch tasks
     * 
     */
    public static String BatchTaskInvoker_DisplayName() {
        return holder.format("BatchTaskInvoker.DisplayName");
    }

    /**
     * Invoke batch tasks
     * 
     */
    public static Localizable _BatchTaskInvoker_DisplayName() {
        return new Localizable(holder, "BatchTaskInvoker.DisplayName");
    }

    /**
     * No such task exists: {0}. Perhaps you meant {1}
     * 
     */
    public static String BatchTaskInvoker_NoSuchTask(Object arg1, Object arg2) {
        return holder.format("BatchTaskInvoker.NoSuchTask", arg1, arg2);
    }

    /**
     * No such task exists: {0}. Perhaps you meant {1}
     * 
     */
    public static Localizable _BatchTaskInvoker_NoSuchTask(Object arg1, Object arg2) {
        return new Localizable(holder, "BatchTaskInvoker.NoSuchTask", arg1, arg2);
    }

    /**
     * Executed Tasks
     * 
     */
    public static String BatchRunAction_DisplayName() {
        return holder.format("BatchRunAction.DisplayName");
    }

    /**
     * Executed Tasks
     * 
     */
    public static Localizable _BatchRunAction_DisplayName() {
        return new Localizable(holder, "BatchRunAction.DisplayName");
    }

    /**
     * No such task exists: {0}. In fact, no batch tasks exist at all
     * 
     */
    public static String BatchTaskInvoker_NoBatchTaskExists(Object arg1) {
        return holder.format("BatchTaskInvoker.NoBatchTaskExists", arg1);
    }

    /**
     * No such task exists: {0}. In fact, no batch tasks exist at all
     * 
     */
    public static Localizable _BatchTaskInvoker_NoBatchTaskExists(Object arg1) {
        return new Localizable(holder, "BatchTaskInvoker.NoBatchTaskExists", arg1);
    }

    /**
     * Batch tasks
     * 
     */
    public static String BatchTaskProperty_DisplayName() {
        return holder.format("BatchTaskProperty.DisplayName");
    }

    /**
     * Batch tasks
     * 
     */
    public static Localizable _BatchTaskProperty_DisplayName() {
        return new Localizable(holder, "BatchTaskProperty.DisplayName");
    }

    /**
     * No such project exists: {0}
     * 
     */
    public static String BatchTaskInvoker_NoSuchProject(Object arg1) {
        return holder.format("BatchTaskInvoker.NoSuchProject", arg1);
    }

    /**
     * No such project exists: {0}
     * 
     */
    public static Localizable _BatchTaskInvoker_NoSuchProject(Object arg1) {
        return new Localizable(holder, "BatchTaskInvoker.NoSuchProject", arg1);
    }

    /**
     * Invoking {0} - {1}{2}
     * 
     */
    public static String BatchTaskInvoker_Invoking(Object arg1, Object arg2, Object arg3) {
        return holder.format("BatchTaskInvoker.Invoking", arg1, arg2, arg3);
    }

    /**
     * Invoking {0} - {1}{2}
     * 
     */
    public static Localizable _BatchTaskInvoker_Invoking(Object arg1, Object arg2, Object arg3) {
        return new Localizable(holder, "BatchTaskInvoker.Invoking", arg1, arg2, arg3);
    }

}
